@@ -1,22 +1,7 @@
-/*  This file is part of the KDevelop PHP Documentation Plugin
+/*
+    SPDX-FileCopyrightText: 2012 Milian Wolff <mail@milianw.de>
 
-    Copyright 2012 Milian Wolff <mail@milianw.de>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "phpdocsmodel.h"
@@ -37,14 +22,15 @@
 #include <KLocalizedString>
 
 #include <QStandardPaths>
+#include <QRegularExpression>
 
 using namespace KDevelop;
 
 PhpDocsModel::PhpDocsModel(QObject* parent)
-    : QAbstractListModel(parent), m_internalFunctionsFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kdevphpsupport/phpfunctions.php"))
+    : QAbstractListModel(parent), m_internalFunctionsFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdevphpsupport/phpfunctions.php")))
 {
     // make sure the php plugin is loaded
-    auto phpLangPlugin = ICore::self()->languageController()->language("Php");
+    auto phpLangPlugin = ICore::self()->languageController()->language(QStringLiteral("Php"));
     if ( !phpLangPlugin ) {
         qCWarning(DOCS) << "could not load PHP language support plugin";
         return;
@@ -78,7 +64,7 @@ void PhpDocsModel::fillModel(const ReferencedTopDUContext& top)
 
     qCDebug(DOCS) << "filling model";
     typedef QPair<Declaration*, int> DeclDepthPair;
-    foreach ( const DeclDepthPair& declpair, top->allDeclarations(top->range().end, top) ) {
+    foreach ( DeclDepthPair declpair, top->allDeclarations(top->range().end, top) ) {
         if ( declpair.first->abstractType() && declpair.first->abstractType()->modifiers() & AbstractType::ConstModifier ) {
             // filter global constants, since they are hard to find in the documentation
             continue;
@@ -111,10 +97,9 @@ QVariant PhpDocsModel::data(const QModelIndex& index, int role) const
             }
             QString ret = dec->toString();
             if ( dec->isFunctionDeclaration() ) {
-                // remove function arguments
-                ret = ret.replace(QRegExp("\\(.+\\)"), "()");
-                // remove return type
-                ret = ret.remove(QRegExp("^[^ ]+ "));
+                static const auto functionArgsPattern = QRegularExpression(QStringLiteral("\\(.+\\)"));
+                static const auto returnTypePattern = QRegularExpression(QStringLiteral("^[^ ]+ "));
+                ret.remove(functionArgsPattern).remove(returnTypePattern);
             }
             return ret;
         }
@@ -146,3 +131,5 @@ DeclarationPointer PhpDocsModel::declarationForIndex(const QModelIndex& index) c
 
     return m_declarations[index.row()];
 }
+
+#include "moc_phpdocsmodel.cpp"
